==> amplify-1.4.0-sources.jar: com/github/stkent/amplify/tracking/managers/TotalEventCountRulesManager.java <==
/**
 * Copyright 2015 Stuart Kent
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License.
 *
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations
 * under the License.
 */
package com.github.stkent.amplify.tracking.managers;

import android.support.annotation.NonNull;
import android.support.annotation.Nullable;

import com.github.stkent.amplify.ILogger;
import com.github.stkent.amplify.tracking.interfaces.ISettings;

public final class TotalEventCountRulesManager extends BaseEventsManager<Integer> {

    public TotalEventCountRulesManager(
            @NonNull final ISettings<Integer> settings,
            @NonNull final ILogger logger) {

        super(settings, logger);
    }

    @NonNull
    @Override
    protected String getTrackedEventDimensionDescription() {
        return "Total count";
    }

    @NonNull
    @Override
    protected String getEventTrackingStatusStringSuffix(@NonNull final Integer cachedEventValue) {
        return "has previously occurred " + cachedEventValue + " times";
    }

    @NonNull
    @Override
    public Integer getUpdatedTrackingValue(@Nullable final Integer cachedTrackingValue) {
        return cachedTrackingValue == null ? 1 : cachedTrackingValue + 1;
    }

}

==> amplify-1.5.1-sources.jar: com/github/stkent/amplify/tracking/managers/TotalEventCountRulesManager.java <==
/**
 * Copyright 2015 Stuart Kent
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License.
 *
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations
 * under the License.
 */
package com.github.stkent.amplify.tracking.managers;

import android.support.annotation.NonNull;
import android.support.annotation.Nullable;

import com.github.stkent.amplify.tracking.interfaces.ISettings;

public final class TotalEventCountRulesManager extends BaseEventsManager<Integer> {

    public TotalEventCountRulesManager(@NonNull final ISettings<Integer> settings) {
        super(settings);
    }

    @NonNull
    @Override
    protected String getTrackedEventDimensionDescription() {
        return "Total count";
    }

    @NonNull
    @Override
    protected String getEventTrackingStatusStringSuffix(@NonNull final Integer cachedEventValue) {
        return "has previously occurred " + cachedEventValue + " times";
    }

    @NonNull
    @Override
    public Integer getUpdatedTrackingValue(@Nullable final Integer cachedTrackingValue) {
        return cachedTrackingValue == null ? 1 : cachedTrackingValue + 1;
    }

}
